/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2014 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* System Name  : WAIT processing which can be performed in a fixed cycle 
* File Name    : r_delay.c
* Version      : Ver 1.00
* Device       : RX Family
* Abstract     : Program example of WAIT processing
* Tool-Chain   : e2 studio (Version 2.2.0.13)
*              : C/C++ Compiler Package for RX Family (V2.01.00)
* OS           : not use
* H/W Platform : Renesas Starter Kit for RX111
* Description  : Waits until the arbitrary cycles specified by the argument elapse. 
* Limitation   : none
*******************************************************************************/
/*******************************************************************************
* History      : DD.MM.YYYY Version  Description
*              : 03.02.2014 1.00     First Release
*******************************************************************************/

void R_DELAY_Us (unsigned long us, unsigned long khz);

/*******************************************************************************
* Outline      : WAIT processing which can be performed in a fixed cycle 
* Header       : none
* Function Name: R_DELAY
* Description  : The function waits until the arbitrary cycles shown in R1 pass.
* Arguments    : R1 : Waiting loop counter
* Return Value : none
*******************************************************************************/
#pragma inline_asm R_DELAY
static void R_DELAY  (unsigned long loop_cnt)
{
    BRA     ?+
    NOP
?:
    NOP
    SUB     #01H,R1
    BNE     ?-

}

/*******************************************************************************
* Outline      : WAIT processing which can be performed in a fixed cycle
               : (for several us)
* Header       : none
* Function Name: R_DELAY_Us
* Description  : The function performed in the fixed cycle is called and 
               : It waits for the WAIT time for several us.
* Arguments    : R1 : Waiting time(us)
               : R2 : Frequency of a ICLK (kHz)
* Return Value : none
*******************************************************************************/
void R_DELAY_Us (unsigned long us, unsigned long khz)
{

    signed long loop_cnt; /* Argument of R_DELAY function */

    /* Calculation of a loop count */
    loop_cnt = us * khz;
    loop_cnt = (loop_cnt / 5000 );      /* Division about cycle of 1 loop */
    loop_cnt = loop_cnt - 4;            /* Overhead is reduced from a loop count. */ 

    /* R_DELAY function is performed when loop_cnt is 1 or more. */
    if(loop_cnt > 0)
    {
        R_DELAY((unsigned long)loop_cnt);
    }
}

/* End of File */

