/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* System Name  : RX111 initialization example
* File Name    : r_init_clock.h
* Version      : Ver 1.01
* Device       : R5F51115ADFM(RX111 Group)
* Abstract     : Program example of RX111 initialization
* Tool-Chain   : e2 studio (Version 2.2.0.11)
*              : C/C++ Compiler Package for RX Family (V2.01.00)
* OS           : not use
* H/W Platform : Renesas Starter Kit for RX111
* Description  : Initialize the clock.
* Limitation   : none
*******************************************************************************/
/*******************************************************************************
* History      : DD.MM.YYYY Version  Description
*              : 01.01.2014 1.00     First Release
*              : 02.03.2015 1.01     RCR.RTCDV setting add
*******************************************************************************/

/* Guards against multiple inclusion */
#ifndef R_INIT_CLOCK_H
#define R_INIT_CLOCK_H

/*******************************************************************************
Macro definitions
*******************************************************************************/
/* The value to select whether to use */
#define B_NOT_USE       (0)
#define B_USE           (1)

/* ==== Please set the main clock ==== */
/* This sample code uses the main clock with the following settings.
   Please change the following settings as necessary. */
#define SEL_MAIN        (B_USE)
/* Frequency : 16 MHz */
#define MAIN_CLOCK_Hz   (16000000L)
/* Drive capability : 16 MHz crystal resonator */
#define REG_MOFCR       (0x20)
/* Wait control register : 32768 cycles (approx. 8.192 ms) */
#define REG_MOSCWTCR    (0x06)

/* ==== Please set the sub-clock ==== */
/* This sample code does not use the sub-clock.
   Please change the following settings as necessary. */
#define SEL_SUB         (B_NOT_USE)     /* Please select whether to use sub-clock as the system clock */
#define SEL_RTC         (B_NOT_USE)     /* Please select whether to use sub-clock as the RTC count source */
/* Frequency : 32.768 kHz */
#define SUB_CLOCK_Hz    (32768L)
/* Wait time for the clock oscillation stabilization : 1.31 s */
#define WAIT_TIME_FOR_SUB_OSCILLATION   (1310000000L)
/* ---- Please select the drive capability ---- */
#define DRIVE_MID       (0x00)          /* Medium drive capacity */
#define DRIVE_HIGH      (0x02)          /* High drive capacity */
#define DRIVE_LOW       (0x04)          /* Low drive capacity */
#define DRIVE_TYP       (0x08)          /* Standard driving ability for the clock */
#define REG_RCR3        (DRIVE_MID)
/* ---- Please select the count mode ---- */
#define CNTMD_CAL       (0)             /* Calendar count mode */
#define CNTMD_BIN       (1)             /* Binary count mode */
#define SEL_CNTMD       (CNTMD_CAL)

/* ==== Please set the HOCO clock ==== */
/* This sample code does not use the HOCO clock.
   Please change the following settings as necessary. */
#define SEL_HOCO        (B_NOT_USE)
/* Wait control register */
#define REG_HOCOWTCR    (0x06)          /* 266 cycles */

/* ==== Please set the PLL clock ==== */
/* This sample code uses the PLL clock with the following settings.
   Please change the following settings as necessary. */
#define SEL_PLL         (B_NOT_USE)
/* Division ratio and multiplication factor : divide-by-2, multiply-by-6 */
#define REG_PLLCR       (0x0B01)

/* ==== Please select the source of the system clock ==== */
#define CLK_HOCO        (0x0100)        /* HOCO */
#define CLK_MAIN        (0x0200)        /* Main clock */
#define CLK_SUB         (0x0300)        /* Sub-clock */
#define CLK_PLL         (0x0400)        /* PLL clock */

/* This sample code uses main clock as the system clock.
   Please change the following settings as necessary. */
#define SEL_SYSCLK      (CLK_MAIN)

/* ==== Please select the internal clock division ratio ==== */
/* This sample code uses the following internal clock division ratio.
   Please change the following settings as necessary. */
#if (SEL_SYSCLK == CLK_PLL)
    #define REG_SCKCR   (0x11000101)    /* ICLK,PCLKD,PCLKB,FCLK: divide-by-2 */
#else
    #define REG_SCKCR   (0x00000000)    /* ICLK,PCLKD,PCLKB,FCLK: no division */
#endif

/* ==== Please select the operating power control mode ==== */
#define SOPCM_MID       (0x00)          /* Middle-speed operating mode */
#define OPCM_MID        (0x02)

#define SOPCM_HIGH      (0x00)          /* High-speed operating mode */
#define OPCM_HIGH       (0x00)

#define SOPCM_LOW       (0x01)          /* Low-speed operating mode */
#define OPCM_LOW        (0x00)

/* This sample code uses the High-speed operating mode.
   Please change the following settings as necessary. */
#define REG_SOPCCR      (SOPCM_HIGH)
#define REG_OPCCR       (OPCM_HIGH)

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void R_INIT_Clock(void);
void CGC_oscillation_main(void);
void CGC_oscillation_HOCO(void);
void CGC_oscillation_sub(void);
void CGC_oscillation_PLL(void);
void CGC_disable_subclk(void);

#endif /* R_INIT_CLOCK_H */

/* End of File */

