/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* System Name  : RX111 initialization example
* File Name    : r_init_port_initialize.h
* Version      : Ver 1.01
* Device       : R5F51115ADFM(RX111 Group)
* Abstract     : Example of port initialization for RX111
* Tool-Chain   : e2 studio (Version 2.2.0.11)
*              : C/C++ Compiler Package for RX Family (V2.01.00)
* OS           : not use
* H/W Platform : Renesas Starter Kit for RX111
* Description  : Initialization of ports.
* Limitation   : none
*******************************************************************************/
/*******************************************************************************
* History      : DD.MM.YYYY Version  Description
*              : 01.01.2014 1.00     First Release
*              : 02.03.2015 1.01     Version up
*******************************************************************************/

/* Guards against multiple inclusion */
#ifndef R_INIT_NON_EXISTENT_PORT_H
#define R_INIT_NON_EXISTENT_PORT_H

/*******************************************************************************
Macro definitions
*******************************************************************************/
#define PIN_SIZE    (64)

#if (PIN_SIZE == 64)
 /* initialize pin data */
 #define DEF_P0PDR_MASK     (0x28)
 #define DEF_P1PDR_MASK     (0xF0)
 #define DEF_P2PDR_MASK     (0xC0)
 #define DEF_P3PDR_MASK     (0x07)
 #define DEF_P4PDR_MASK     (0x5F)
 #define DEF_P5PDR_MASK     (0x30)
 #define DEF_PAPDR_MASK     (0x5B)
 #define DEF_PBPDR_MASK     (0xEB)
 #define DEF_PCPDR_MASK     (0xFF)
 #define DEF_PEPDR_MASK     (0xFF)
 #define DEF_PJPDR_MASK     (0xC0)

 /* pin is initialized with this value */
 #define DEF_P0PDR          (0xD7)
 #define DEF_P1PDR          (0x0F)
 #define DEF_P2PDR          (0x3F)
 #define DEF_P3PDR          (0xD8)
 #define DEF_P4PDR          (0xA0)
 #define DEF_P5PDR          (0xCF)
 #define DEF_PAPDR          (0xA4)
 #define DEF_PBPDR          (0x14)
 #define DEF_PCPDR          (0x00)
 #define DEF_PEPDR          (0x00)
 #define DEF_PJPDR          (0x3F)

#elif (PIN_SIZE == 48)
 /* initialize pin data */
 #define DEF_P0PDR_MASK     (0x00)
 #define DEF_P1PDR_MASK     (0xF0)
 #define DEF_P2PDR_MASK     (0xC0)
 #define DEF_P3PDR_MASK     (0x00)
 #define DEF_P4PDR_MASK     (0x47)
 #define DEF_P5PDR_MASK     (0x00)
 #define DEF_PAPDR_MASK     (0x5A)
 #define DEF_PBPDR_MASK     (0x2B)
 #define DEF_PCPDR_MASK     (0xFF)
 #define DEF_PEPDR_MASK     (0x9F)
 #define DEF_PJPDR_MASK     (0xC0)

 /* pin is initialized with this value */
 #define DEF_P0PDR          (0xFF)
 #define DEF_P1PDR          (0x0F)
 #define DEF_P2PDR          (0x3F)
 #define DEF_P3PDR          (0xDF)
 #define DEF_P4PDR          (0xB8)
 #define DEF_P5PDR          (0xFF)
 #define DEF_PAPDR          (0xA5)
 #define DEF_PBPDR          (0xD4)
 #define DEF_PCPDR          (0x00)
 #define DEF_PEPDR          (0x60)
 #define DEF_PJPDR          (0x3F)

#elif (PIN_SIZE == 40)
 /* initialize pin data */
 #define DEF_P0PDR_MASK     (0x00)
 #define DEF_P1PDR_MASK     (0xF0)
 #define DEF_P2PDR_MASK     (0xC0)
 #define DEF_P3PDR_MASK     (0x04)
 #define DEF_P4PDR_MASK     (0x46)
 #define DEF_P5PDR_MASK     (0x00)
 #define DEF_PAPDR_MASK     (0x5A)
 #define DEF_PBPDR_MASK     (0x09)
 #define DEF_PCPDR_MASK     (0x10)
 #define DEF_PEPDR_MASK     (0x1F)
 #define DEF_PJPDR_MASK     (0xC0)

 /* pin is initialized with this value */
 #define DEF_P0PDR          (0xFF)
 #define DEF_P1PDR          (0x0F)
 #define DEF_P2PDR          (0x3F)
 #define DEF_P3PDR          (0xDB)
 #define DEF_P4PDR          (0xB9)
 #define DEF_P5PDR          (0xFF)
 #define DEF_PAPDR          (0xA5)
 #define DEF_PBPDR          (0xF6)
 #define DEF_PCPDR          (0xEF)
 #define DEF_PEPDR          (0xE0)
 #define DEF_PJPDR          (0x3F)
 
#elif (PIN_SIZE == 36)
 /* initialize pin data */
 #define DEF_P0PDR_MASK     (0x00)
 #define DEF_P1PDR_MASK     (0xF0)
 #define DEF_P2PDR_MASK     (0x80)
 #define DEF_P3PDR_MASK     (0x00)
 #define DEF_P4PDR_MASK     (0x06)
 #define DEF_P5PDR_MASK     (0x00)
 #define DEF_PAPDR_MASK     (0x58)
 #define DEF_PBPDR_MASK     (0x09)
 #define DEF_PCPDR_MASK     (0x10)
 #define DEF_PEPDR_MASK     (0x1F)
 #define DEF_PJPDR_MASK     (0xC0)

 /* pin is initialized with this value */
 #define DEF_P0PDR          (0xFF)
 #define DEF_P1PDR          (0x0F)
 #define DEF_P2PDR          (0x7F)
 #define DEF_P3PDR          (0xDF)
 #define DEF_P4PDR          (0xF9)
 #define DEF_P5PDR          (0xFF)
 #define DEF_PAPDR          (0xA7)
 #define DEF_PBPDR          (0xF6)
 #define DEF_PCPDR          (0xEF)
 #define DEF_PEPDR          (0xE0)
 #define DEF_PJPDR          (0x3F)
 
#else

#endif

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void R_INIT_Port_Initialize(void);

#endif /* R_INIT_NON_EXISTENT_PORT_H */

/* End of File */

